package example;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.servicemix.nmr.api.Channel;
import org.apache.servicemix.nmr.api.Endpoint;
import org.apache.servicemix.nmr.api.Exchange;
import org.apache.servicemix.nmr.api.Message;
import org.apache.servicemix.nmr.api.Status;

public class BinaryAttachmentReader implements Endpoint
{
	static private final Log LOG = LogFactory.getLog( BinaryAttachmentReader.class );

	private Channel myChannel = null;

	public void process( Exchange msgXchg )
	{
		Status status = msgXchg.getStatus();
		if( status.equals( Status.Active ) )
		{
			Message outMsg = msgXchg.getOut();
			if( outMsg != null )
			{
				Message in = msgXchg.getIn();

				if( in.getAttachments().size() > 0 )
				{
					Object attachObj = in.getAttachment( BinaryFileToAttachment.ATTACHMENT_KEY );
					LOG.info( "Successfully received attachment of type " + attachObj.getClass().getCanonicalName() );
				}
				else
				{
					LOG.info( "Message has no attachments" );
					outMsg = in.copy();
					outMsg.setBody( "<NoAttachment/>" );
					msgXchg.setOut( outMsg );
				}
			}
			else
			{
				LOG.info( "Received InOnly message, but we need an InOut" );
			}
			this.myChannel.send( msgXchg );
		}
		else
		{
			LOG.info( "Received message in response path" );
		}
	}

	public void setChannel( Channel aChannel )
	{
		this.myChannel = aChannel;
	}
}
