package example;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.servicemix.nmr.api.Channel;
import org.apache.servicemix.nmr.api.Endpoint;
import org.apache.servicemix.nmr.api.Exchange;
import org.apache.servicemix.nmr.api.Message;
import org.apache.servicemix.nmr.api.Status;

public class BinaryFileToAttachment implements Endpoint
{
	static public final String ATTACHMENT_KEY = "FILE_CONTENTS";

	private static final transient Log LOG = LogFactory.getLog(BinaryFileToAttachment.class);

	private Channel myChannel = null;

	public BinaryFileToAttachment()
	{
		LOG.trace( "Instantiated Binary Endpoint" );
	}

	public void process( Exchange msgXchg )
	{
		Status status = msgXchg.getStatus();
		if( status.equals( Status.Active ) )
		{
			Message outMsg = msgXchg.getOut();
			if( outMsg != null )
			{
				Message in = msgXchg.getIn();
				Object objBody = in.getBody();

				// Convert file contents to attachment
				outMsg = in.copy();
				outMsg.setBody( "<BinaryAttachment/>" );
				outMsg.addAttachment( BinaryFileToAttachment.ATTACHMENT_KEY, objBody );
				LOG.info( "Attachment count for out is " + outMsg.getAttachments().size() );
				msgXchg.setOut( outMsg );
			}
			else
			{
				LOG.debug( "Received InOnly message, but we need an InOut" );
			}
			this.myChannel.send( msgXchg );
		}
		else
		{
			LOG.debug( "Received message in response path" );
		}
	}

	public void setChannel( Channel aChannel )
	{
		this.myChannel = aChannel;
	}

	@PostConstruct
	public void init()
	{
		LOG.trace( "Inited Binary Endpoint" );
	}

	@PreDestroy
	public void shutdown()
	{
		LOG.trace( "Shut down Binary Endpoint" );
	}
}
